#!/usr/bin/python
# -*- coding: utf-8 -*-

import unittest
from viacep import ViaCEP

class TestCase(unittest.TestCase):

    def test_localidade(self):
        d = ViaCEP('78048000')
        data = d.getDadosCEP()
        self.assertEqual(data['localidade'], 'Cuiabá')

    def test_logradouro(self):
        d = ViaCEP('78048000')
        data = d.getDadosCEP()
        self.assertEqual(data['logradouro'], 'Avenida Miguel Sutil')

    def test_bairro(self):
        d = ViaCEP('78048000')
        data = d.getDadosCEP()
        self.assertEqual(data['bairro'], 'Alvorada')

    def test_uf(self):
        d = ViaCEP('78048000')
        data = d.getDadosCEP()
        self.assertEqual(data['uf'], 'MT')

    def test_ibge(self):
        d = ViaCEP('78048000')
        data = d.getDadosCEP()
        self.assertEqual(data['ibge'], '5103403')

if __name__ == '__main__':
    unittest.main()



#!/usr/bin/python
# -*- coding: utf-8 -*-

import json
import requests
from sys import exit

__version__ = '1.3.1'

class ViaCEP:

	def __init__(self, cep):
		self.cep = cep

	def getDadosCEP(self):
		url_api = ('http://www.viacep.com.br/ws/%s/json' % self.cep)
		try:
			req = requests.get(url_api)
			if req.status_code == 200:
				dados_json = json.loads(req.text)
				return dados_json
			else:
				exit("Status code error: %s" % req.status_code)
		except requests.exceptions.Timeout as err:
			print(err)
			exit(1)
		except requests.exceptions.TooManyRedirects as err:
			print(err)
			exit(1)
		except requests.exceptions.HTTPError as err:
			print(err)
			exit(1)
		except requests.exceptions.RequestException as err:
			print(err)
			exit(1)


# -*- coding: utf-8 -*-

from distutils.core import setup
from setuptools import find_packages

import viacep

version = viacep.__version__

install_requires = [
    'requests>=2.9.1'
]

long_description = "Pesquisar informações de CEP's do Brasil pelo webservice http://www.viacep.com.br"

setup(
    name='viacep',
    version=version,
    author='Leonardo Gregianin',
    author_email='leogregianin@gmail.com',
    scripts=['viacep.py', 'test_viacep.py', 'sample.py', 'README.md'],
    url='https://github.com/leogregianin/viacep-python',
    license='LICENSE',
    description='Consulta CEP pelo webservice do ViaCEP.com.br',
    long_description=long_description,
    install_requires=install_requires,
    platforms = 'any',
    packages=[],
    classifiers = [
        'Programming Language :: Python',
        'Programming Language :: Python :: 2',
        'Programming Language :: Python :: 2.7',
        'Programming Language :: Python :: 3',
        'Programming Language :: Python :: 3.5',
        'Development Status :: 4 - Beta',
        'Natural Language :: English',
        'Environment :: Console',
        'Intended Audience :: Developers',
        'License :: OSI Approved :: MIT License',
        'Operating System :: OS Independent',
        'Topic :: Software Development :: Libraries :: Python Modules'
    ],	
)